==> quay-registry-container-v3.5.4-1.tar.gz: package/AUTHORS.md <==
TypeScript is authored by:
* Aaron Holmes
* Abubaker Bashir
* Adam Freidin
* Adi Dahiya
* Ahmad Farid
* Akshar Patel
* Alex Eagle
* Alexander Kuvaev
* Alexander Rusakov 
* Ali Sabzevari
* Aliaksandr Radzivanovich
* Anatoly Ressin 
* Anders Hejlsberg
* Andreas Martin
* Andrej Baran 
* Andrew Ochsner 
* Andrew Z Allen
* András Parditka 
* Andy Hanson
* Anil Anar
* Anton Khlynovskiy 
* Anton Tolmachev
* Anubha Mathur 
* Arnav Singh
* Arthur Ozga
* Asad Saeeduddin
* Avery Morin
* Basarat Ali Syed
* Ben Duffield
* Ben Mosher 
* Bill Ticehurst
* Blake Embrey
* @bootstraponline
* Bowden Kelly
* Brett Mayen
* Bryan Forbes
* Caitlin Potter
* Charly POLY 
* Chris Bubernak
* Christophe Vidal 
* Chuck Jazdzewski
* Colby Russell
* Colin Snover
* Cotton Hou 
* Cyrus Najmabadi
* Dafrok Zhang
* Dahan Gong
* Dan Corder
* Dan Quirk
* Daniel Hollocher
* Daniel Rosenwasser
* David Kmenta
* David Li
* David Sheldrick 
* David Souther
* Denis Nedelyaev
* Dick van den Brink
* Dirk Bäumer
* Dirk Holtwick
* Dom Chen 
* Doug Ilijev
* Elisée Maurer
* Emilio García-Pumarino
* Eric Tsang
* Erik Edrosa
* Ethan Resnick 
* Ethan Rubio
* Evan Martin
* Evan Sebastian
* Eyas Sharaiha
* Fabian Cook 
* @falsandtru
* @flowmemo
* Frank Wallis
* Franklin Tse
* František Žiacik
* Gabe Moothart 
* Gabriel Isenberg
* Gilad Peleg
* Godfrey Chan 
* Graeme Wicksted
* Guilherme Oenning
* Guillaume Salles
* Guy Bedford
* Harald Niesche
* Herrington Darkholme
* Homa Wong 
* Iain Monro
* Ingvar Stepanyan
* Isiah Meadows
* Ivo Gabe de Wolff
* Jakub Młokosiewicz 
* James Whitney
* Jason Freeman
* Jason Killian
* Jason Ramsay
* JBerger
* Jed Mao
* Jeffrey Morlan
* Jesse Schalken
* Jiri Tobisek
* Joel Day 
* Joey Wilson
* Johannes Rieken
* John Vilk
* Jonathan Bond-Caron
* Jonathan Park
* Jonathan Toland
* Jonathan Turner
* Jonathon Smith
* Josh Abernathy 
* Josh Kalderimis
* Josh Soref
* Juan Luis Boya García
* Julian Williams
* Justin Bay 
* Justin Johansson 
* Kagami Sascha Rosylight
* Kanchalai Tanglertsampan
* Keith Mashinter
* Ken Howard
* Kenji Imamula
* Kevin Lang 
* Klaus Meinhardt 
* Kyle Kelley
* Kārlis Gaņģis
* Lorant Pinter
* Lucien Greathouse
* Lukas Elmer 
* Manish Giri
* Marin Marinov
* Marius Schulz 
* Martin Vseticka
* Masahiro Wakame
* Matt McCutchen
* Mattias Buelens
* Mattias Buelens 
* Max Deepfield
* Micah Zoltu
* Michael 
* Michael Bromley
* Mohamed Hegazy
* Myles Megyesi 
* Nathan Shively-Sanders
* Nathan Yee
* Nicolas Henry
* Nima Zahedi
* Noah Chen 
* Noj Vek
* Oleg Mihailik
* Oleksandr Chekhovskyi
* Omer Sheikh 
* Oskar Segersva¨rd
* Patrick Zhong
* Paul Jolly
* Paul van Brenk
* @pcbro
* Pedro Maltez
* Perry Jiang
* Peter Burns
* Philip Bulley
* Piero Cangianiello
* @piloopin
* Prayag Verma
* @progre
* Punya Biswal
* Rado Kirov
* Raj Dosanjh
* Richard Knoll
* Richard Sentino
* Robert Coie
* Rohit Verma
* Ron Buckton
* Rostislav Galimsky 
* Rowan Wyborn
* Ryan Cavanaugh
* Ryohei Ikegami
* Sam El-Husseini 
* Sarangan Rajamanickam
* Sergey Shandar 
* Sheetal Nandi
* Shengping Zhong
* Shyyko Serhiy
* Simon Hürlimann
* Slawomir Sadziak 
* Solal Pirelli
* Stan Thomas
* Stanislav Sysoev
* Steve Lucco
* Sudheesh Singanamalla 
* Sébastien Arod
* @T18970237136
* Tarik Ozket
* Tetsuharu Ohzeki
* Thomas Loubiou
* Tien Hoanhtien
* Tim Lancina 
* Tim Perry
* Tim Viiding-Spader
* Tingan Ho
* Todd Thomson
* togru
* Tomas Grubliauskas
* Torben Fitschen 
* TruongSinh Tran-Nguyen
* Vidar Tonaas Fauske
* Viktor Zozulyak
* Vilic Vane
* Vladimir Matveev
* Wesley Wigham
* York Yao
* @yortus
* Yuichi Nukiyama
* Zev Spitz
* Zhengbo Li

==> quay-registry-container-v3.5.6-4.tar.gz: package/AUTHORS.md <==
TypeScript is authored by:
* Aaron Holmes
* Abubaker Bashir
* Adam Freidin
* Adi Dahiya
* Aditya Daflapurkar
* Adnan Chowdhury 
* Adrian Leonhard 
* Adrien Gibrat 
* Ahmad Farid
* Akshar Patel
* Alan Agius 
* Alex Chugaev 
* Alex Eagle
* Alex Khomchenko 
* Alex Ryan 
* Alexander Kuvaev
* Alexander Rusakov 
* Alexander Tarasyuk
* Ali Sabzevari
* Aliaksandr Radzivanovich
* Aluan Haddad 
* Anatoly Ressin 
* Anders Hejlsberg
* Andreas Martin
* Andrej Baran 
* Andrew Casey 
* Andrew Faulkner 
* Andrew Ochsner 
* Andrew Stegmaier 
* Andrew Z Allen
* András Parditka 
* Andy Hanson
* Anil Anar
* Anton Khlynovskiy 
* Anton Tolmachev
* Anubha Mathur 
* Armando Aguirre 
* Arnaud Tournier 
* Arnav Singh
* Artem Tyurin 
* Arthur Ozga
* Asad Saeeduddin
* Avery Morin
* Basarat Ali Syed
* @begincalendar
* Ben Duffield
* Ben Mosher 
* Benjamin Bock 
* Benjamin Lichtman 
* Benny Neugebauer 
* Bill Ticehurst
* Blaine Bublitz 
* Blake Embrey
* @bootstraponline
* Bowden Kelly
* Bowden Kenny
* Brandon Slade 
* Brett Mayen
* Bryan Forbes
* Caitlin Potter
* Cameron Taggart 
* @cedvdb
* Charles Pierce 
* Charly POLY 
* Chris Bubernak
* Christophe Vidal 
* Chuck Jazdzewski
* Colby Russell
* Colin Snover
* Cotton Hou 
* Cyrus Najmabadi
* Dafrok Zhang
* Dahan Gong
* Dan Corder
* Dan Quirk
* Daniel Hollocher
* Daniel Król 
* Daniel Lehenbauer
* Daniel Rosenwasser
* David Kmenta
* David Li
* David Sheldrick 
* David Souther
* Denis Nedelyaev
* Derek P Sifford 
* Dhruv Rajvanshi 
* Dick van den Brink
* Diogo Franco (Kovensky) 
* Dirk Bäumer
* Dirk Holtwick
* Dom Chen 
* Donald Pipowitch 
* Doug Ilijev
* @e-cloud
* Ecole Keine
* Elisée Maurer
* Emilio García-Pumarino
* Eric Grube 
* Eric Tsang
* Erik Edrosa
* Erik McClenney 
* Esakki Raj 
* Ethan Resnick 
* Ethan Rubio
* Eugene Timokhov 
* Evan Martin
* Evan Sebastian
* Eyas Sharaiha
* Fabian Cook 
* @falsandtru
* Filipe Silva 
* @flowmemo
* Francois Wouts 
* Frank Wallis
* Franklin Tse
* František Žiacik
* Gabe Moothart 
* Gabriel Isenberg
* Gilad Peleg
* Godfrey Chan 
* Graeme Wicksted
* Guilherme Oenning
* Guillaume Salles
* Guy Bedford
* Halasi Tamás 
* Harald Niesche
* Hendrik Liebau 
* Henry Mercer 
* Herrington Darkholme
* Holger Jeromin 
* Homa Wong 
* Iain Monro
* @IdeaHunter
* Igor Novozhilov
* Ika 
* Ingvar Stepanyan
* Isiah Meadows
* Ivan Enderlin 
* Ivo Gabe de Wolff
* Iwata Hidetaka 
* Jack Williams 
* Jakub Korzeniowski
* Jakub Młokosiewicz 
* James Henry 
* James Whitney
* Jan Melcher 
* Jason Freeman
* Jason Jarrett 
* Jason Killian
* Jason Ramsay
* JBerger
* Jed Mao
* Jeffrey Morlan
* Jesse Schalken
* Jing Ma 
* Jiri Tobisek
* Joe Calzaretta 
* Joe Chung 
* Joel Day 
* Joey Wilson
* Johannes Rieken
* John Vilk
* Jonathan Bond-Caron
* Jonathan Park
* Jonathan Toland
* Jonathan Turner
* Jonathon Smith
* Jordi Oliveras Rovira 
* Joscha Feth 
* Josh Abernathy 
* Josh Goldberg 
* Josh Kalderimis
* Josh Soref
* Juan Luis Boya García
* Julian Williams
* Justin Bay 
* Justin Johansson 
* K. Preißer
* Kagami Sascha Rosylight
* Kanchalai Tanglertsampan
* Kate Miháliková 
* Keith Mashinter
* Ken Howard
* Kenji Imamula
* Kevin Donnelly 
* Kevin Lang 
* Khải 
* Kitson Kelly 
* Klaus Meinhardt 
* Kris Zyp 
* Kyle Kelley
* Kārlis Gaņģis
* Lorant Pinter
* Lucien Greathouse
* Lukas Elmer 
* Maarten Sijm 
* Magnus Hiie 
* Magnus Kulke 
* Manish Giri
* Marin Marinov
* Marius Schulz 
* Martin Hiller 
* Martin Vseticka
* Martyn Janes 
* Masahiro Wakame
* Matt Bierner 
* Matt McCutchen
* Matt Mitchell 
* Mattias Buelens
* Mattias Buelens 
* Max Deepfield
* Maxwell Paul Brickner 
* @meyer
* Micah Zoltu
* @micbou
* Michael 
* Michael Bromley
* Mike Busyrev 
* Mike Morearty 
* Mine Starks 
* Mohamed Hegazy
* Mohsen Azimi 
* Myles Megyesi 
* Natalie Coley
* Nathan Shively-Sanders
* Nathan Yee
* Nicolas Henry
* @nieltg
* Nima Zahedi
* Noah Chen 
* Noel Varanda 
* Noj Vek
* Oleg Mihailik
* Oleksandr Chekhovskyi
* Omer Sheikh 
* Orta Therox
* Oskar Segersva¨rd
* Oussama Ben Brahim 
* Patrick Zhong
* Paul Jolly
* Paul Koerbitz 
* Paul van Brenk
* @pcbro
* Pedro Maltez
* Perry Jiang
* Peter Burns
* Philip Bulley
* Philippe Voinov 
* Piero Cangianiello
* @piloopin
* Prayag Verma
* Priyantha Lankapura 
* @progre
* Punya Biswal
* Rado Kirov
* Raj Dosanjh
* Reiner Dolp 
* Remo H. Jansen 
* @rhysd
* Ricardo N Feliciano 
* Richard Karmazín 
* Richard Knoll
* Richard Sentino
* Robert Coie
* Rohit Verma
* Ron Buckton
* Rostislav Galimsky 
* Rowan Wyborn
* Ryan Cavanaugh
* Ryohei Ikegami
* Sam El-Husseini 
* Sarangan Rajamanickam
* Sean Barag 
* Sergey Rubanov
* Sergey Shandar 
* Sergii Bezliudnyi 
* Sharon Rolel 
* Sheetal Nandi
* Shengping Zhong
* Shyyko Serhiy
* Simon Hürlimann
* Slawomir Sadziak 
* Solal Pirelli
* Soo Jae Hwang 
* Stan Thomas
* Stanislav Iliev 
* Stanislav Sysoev
* Stas Vilchik 
* Stephan Ginthör 
* Steve Lucco
* Sudheesh Singanamalla 
* Sébastien Arod
* @T18970237136
* @t_
* Taras Mankovski 
* Tarik Ozket
* Tetsuharu Ohzeki
* Thomas den Hollander 
* Thomas Loubiou
* Tien Hoanhtien
* Tim Lancina 
* Tim Perry
* Tim Viiding-Spader
* Tingan Ho
* Todd Thomson
* togru
* Tomas Grubliauskas
* Torben Fitschen 
* @TravCav
* TruongSinh Tran-Nguyen
* Tycho Grouwstra 
* Vadi Taslim 
* Vakhurin Sergey 
* Vidar Tonaas Fauske
* Viktor Zozulyak
* Vilic Vane
* Vladimir Kurchatkin 
* Vladimir Matveev
* Wenlu Wang 
* Wesley Wigham
* William Orr 
* Wilson Hobbs 
* York Yao
* @yortus
* Yuichi Nukiyama
* Yuval Greenfield 
* Zeeshan Ahmed 
* Zev Spitz
* Zhengbo Li
* @Zzzen
